@@ -46,6 +46,8 @@ class PraatLoader:
         com = [self.praat, os.path.join(self.script_dir,name)] + map(str,args)
         p = subprocess.Popen(com,stdout=subprocess.PIPE,stderr=subprocess.PIPE,stdin=subprocess.PIPE)
         stdout, stderr = p.communicate()
+        if stderr != '':
+            print stderr
         return stdout
 
 
